﻿using System;
using System.Linq;
using System.Net;
using System.Collections.ObjectModel;
using System.IO;
using System.Threading.Tasks;
using System.Xml;
using System.ServiceModel.Syndication;
using System.Windows.Media.Imaging;

namespace Async.Workers
{
	class TheOldWay : IDoWork
	{
		private static readonly Uri FlickrRss = new Uri("http://api.flickr.com/services/feeds/photos_public.gne");

		private ObservableCollection<FlickrImage> _images;

		public Task DoWorkAsync(ObservableCollection<FlickrImage> images)
		{
			_images = images;

			WebClient wc = new WebClient();
			wc.DownloadStringCompleted += wc_DownloadStringCompleted;
			wc.DownloadStringAsync(FlickrRss, images);
			return null; //no concept of tasks yet
		}

		void wc_DownloadStringCompleted(object sender, DownloadStringCompletedEventArgs e)
		{
			string str = e.Result;

			StringReader sr = new StringReader(str);
			XmlReader reader = XmlReader.Create(sr);
			SyndicationFeed feed = SyndicationFeed.Load(reader);

			foreach(SyndicationItem item in feed.Items)
			{
				Uri uri = (from link in item.Links where link.RelationshipType == "enclosure" select link.Uri).FirstOrDefault();

				WebClient wc = new WebClient();
				wc.DownloadDataCompleted += wc_DownloadDataCompleted;
				wc.DownloadDataAsync(uri, item);
			}
		}

		void wc_DownloadDataCompleted(object sender, DownloadDataCompletedEventArgs e)
		{
			byte[] data = e.Result;

			MemoryStream ms = new MemoryStream(data);
			BitmapImage bi = new BitmapImage();

			bi.BeginInit();
			bi.StreamSource = ms;
			bi.EndInit();

			FlickrImage fi = new FlickrImage();
			fi.Image = bi;
			fi.Title = (e.UserState as SyndicationItem).Title.Text;
			_images.Add(fi);
		}

		public void Cancel()
		{
		}
	}
}
